to_string_pretty

Function to_string_pretty 

pub fn to_string_pretty<T: Serialize>(value: &T, indent: &str) -> Result<String>
Serialize any type that implements Serialize into a pretty-printed JHON string.

This is a convenience function that uses the Jhon wrapper internally.