pub fn to_string_pretty<T: Serialize>(value: &T, indent: &str) -> Result<String>Expand description
Serialize any type that implements Serialize into a pretty-printed JHON string.
This is a convenience function that uses the Jhon wrapper internally.